@@ -19,25 +19,22 @@ module Gem
     @default_specifications_dir = nil
   end
 
-  if ENV["BUNDLER_SPEC_WINDOWS"]
-    @@win_platform = true # rubocop:disable Style/ClassVars
-  end
-
-  if ENV["BUNDLER_SPEC_PLATFORM"]
-    class Platform
-      @local = new(ENV["BUNDLER_SPEC_PLATFORM"])
+  spec_platform = ENV["BUNDLER_SPEC_PLATFORM"]
+  if spec_platform
+    if /mingw|mswin/.match?(spec_platform)
+      @@win_platform = nil # rubocop:disable Style/ClassVars
+      RbConfig::CONFIG["host_os"] = spec_platform.gsub(/^[^-]+-/, "").tr("-", "_")
     end
-    @platforms = [Gem::Platform::RUBY, Gem::Platform.local]
+
+    RbConfig::CONFIG["arch"] = spec_platform
+
+    class Platform
+      @local = nil
+    end
+    @platforms = []
   end
 
   if ENV["BUNDLER_SPEC_GEM_SOURCES"]
     self.sources = [ENV["BUNDLER_SPEC_GEM_SOURCES"]]
   end
-
-  # We only need this hack for rubygems versions without the BundlerVersionFinder
-  if Gem.rubygems_version < Gem::Version.new("2.7.0")
-    @path_to_default_spec_map.delete_if do |_path, spec|
-      spec.name == "bundler"
-    end
-  end
 end
